@@ -23,14 +23,7 @@ SOFTWARE.
 """
 
 # Typing imports
-from typing import (
-    Optional,
-    Union,
-    Callable,
-    final,
-    List,
-    Literal
-)
+from typing import Optional, Union, Callable, final, List, Literal
 
 # Package imports
 from pathlib import Path
@@ -44,48 +37,20 @@ import requests.exceptions
 
 # Disspy imports
 from disspy import errors
-from disspy.typ import (
-    TypeOf,
-    Event,
-    MISSING
-)
+from disspy.typ import TypeOf, MISSING
 from disspy.activity import Activity
 import disspy.app_commands as appc
-from disspy.channel import (
-    DisChannel,
-    DisDmChannel,
-    DisMessage,
-    DmMessage
-)
-from disspy.http import (
-    DisApi,
-    DisFlags,
-    ChannelId,
-    ThreadId,
-    GuildId,
-    UserId
-)
+from disspy.channel import DisChannel, DisDmChannel, DisMessage, DmMessage
+from disspy.http import DisApi, DisFlags, ChannelId, ThreadId, GuildId, UserId
 from disspy.embed import DisEmbed
 from disspy.guild import DisGuild
 from disspy.user import DisUser
-from disspy.thread import (
-    DisNewsThread,
-    DisThread,
-    DisPrivateThread
-)
-from disspy.abstract import (
-    Channel,
-    Message,
-    Thread
-)
+from disspy.thread import DisNewsThread, DisThread, DisPrivateThread
+from disspy.abstract import Channel, Message, Thread
 from disspy.state import ConnectionState
 from disspy.application import Application
 
-__all__: tuple = (
-    "DisBotStatus",
-    "DisBotEventType",
-    "DisBot"
-)
+__all__: tuple = ("DisBotStatus", "DisBotEventType", "DisBot")
 
 # For Type Hints
 Wrapper = Callable
@@ -103,7 +68,7 @@ _all_basic_events = [
     "reaction",  # On reaction add
     "reactionr",  # On reaction remove
     "typing",  # Typing start
-    "dm_typing"  # Typig start in dm channel
+    "dm_typing",  # Typig start in dm channel
 ]
 
 
@@ -111,13 +76,14 @@ _all_basic_events = [
 # For code readable #
 #####################
 
+
 async def blank():
-    """ Blank method """
+    """Blank method"""
     return
 
 
 def ignore():
-    """ Ignore """
+    """Ignore"""
     return
 
 
@@ -137,8 +103,14 @@ class _BotLogger:
 
         tformat = "%d/%d/%d %d:%d:%d"
 
-        _time = tformat % (_datetime.year, _datetime.month, _datetime.day,
-                           _datetime.hour, _datetime.minute, _datetime.second)
+        _time = tformat % (
+            _datetime.year,
+            _datetime.month,
+            _datetime.day,
+            _datetime.hour,
+            _datetime.minute,
+            _datetime.second,
+        )
 
         self.logs.append(f"[{_time}] {msg}")
 
@@ -154,15 +126,12 @@ class DisBotStatus:
     bot.run(disspy.DisBotStatus.DND)
 
     bot.run(disspy.DisBotStatus.IDLE)
-
-    And you may use status in __init__()
-    bot = disspy.DisBot(token="TOKEN", status=disspy.DisBotStatus.ONLINE)
     """
 
-    ONLINE = "online"
-    DND = "dnd"
-    INVISIBLE = "invisible"
-    IDLE = "idle"
+    ONLINE: Literal["online"] = "online"
+    DND: Literal["dnd"] = "dnd"
+    INVISIBLE: Literal["invisible"] = "invisible"
+    IDLE: Literal["idle"] = "idle"
 
     def __all__(self) -> list:
         """
@@ -171,9 +140,9 @@ class DisBotStatus:
         :return list: All varibles in this class
         """
         return [self.ONLINE, self.DND, self.INVISIBLE, self.IDLE]
-
-    def __str__(self) -> str:
-        return "online"
+    
+    def __type__(self) -> type:
+        return str
 
 
 @final
@@ -189,32 +158,21 @@ class DisBotEventType:
         await message.channel.send('Test!')
     """
 
-    ON_MESSAGEC: str = "messagec"
-    ON_MESSAGEU: str = "messageu"
-    ON_MESSAGED: str = "messaged"
-    ON_DMESSAGEC: str = "dmessagec"
-    ON_DMESSAGEU: str = "dmessageu"
-    ON_DMESSAGED: str = "dmessaged"
-    ON_READY: str = "ready"
-    ON_CLOSE: str = "close"
-    ON_REACTION: str = "reaction"
-    ON_REACTIONR: str = "reactionr"
-    ON_TYPING: str = "typing"
-    ON_DM_TYPING: str = "dm_typing"
+    MESSAGEC: str = "messagec"
+    MESSAGEU: str = "messageu"
+    MESSAGED: str = "messaged"
+    DMESSAGEC: str = "dmessagec"
+    DMESSAGEU: str = "dmessageu"
+    DMESSAGED: str = "dmessaged"
+    READY: str = "ready"
+    CLOSE: str = "close"
+    REACTION: str = "reaction"
+    REACTIONR: str = "reactionr"
+    TYPING: str = "typing"
+    DM_TYPING: str = "dm_typing"
 
-    def __all__(self) -> list:
-        """
-        Returns all varibles in this class
-        -----
-        :return list: All varibles in this class
-        """
-        return [self.ON_READY, self.ON_MESSAGEC, self.ON_MESSAGEU,
-                self.ON_MESSAGED, self.ON_DMESSAGEC, self.ON_DMESSAGEU,
-                self.ON_DMESSAGED, self.ON_CLOSE, self.ON_REACTION,
-                self.ON_REACTIONR, self.ON_TYPING, self.ON_DM_TYPING]
-
-    def __str__(self) -> str:
-        return "ready"
+    def __type__(self) -> type:
+        return str
 
 
 @final
@@ -228,20 +186,20 @@ class DisBot:
     def _raise_unathorized_error(self) -> None:
         raise errors.Unauthorized()
 
-    def __init__(self, token: str,
-                 status: Optional[Literal['online', 'dnd', 'invisible', 'idle']] = None,
-                 flags: Optional[TypeOf(DisFlags)] = None,
-                 activity: Optional[Union[Activity, dict]] = None) -> None:
-        """
-        Create bot
-        -----
-        :param token: Discord Developers Portal Bot Token
-        :param status: Status that use in run()
-        :param flags: Flags (Intents) for bot (default is 512)
+    def __init__(
+        self,
+        token: str,
+        flags: Optional[TypeOf[DisFlags]] = None
+    ) -> None:
+        """__init__
+
+        Args:
+            token (str): Bot token from Discord developers portal
+            flags (Optional[TypeOf[DisFlags], optional): Flags of bot. Defaults to None.
         """
 
         _u = "https://discord.com/api/v10/users/@me"
-        test_j = get(_u, headers={'Authorization': f'Bot {token}'}).json()
+        test_j = get(_u, headers={"Authorization": f"Bot {token}"}).json()
 
         try:
             if test_j["message"] == "401: Unauthorized" and test_j["code"] == 0:
@@ -250,6 +208,8 @@ class DisBot:
         except KeyError:
             ignore()
 
+        del test_j, _u  # Delete variables
+
         self.token: str = str(token)
 
         if flags is None:
@@ -257,14 +217,7 @@ class DisBot:
         else:
             self.intflags = flags
 
-        if isinstance(activity, Activity):
-            activity = activity.json()
-        elif activity is None:
-            activity = {}
-
-        self._act = activity
-
-        self.status = status
+        self.status = None
         self.debug = False
         self._logger = _BotLogger()
         self._state = ConnectionState(token)
@@ -285,20 +238,15 @@ class DisBot:
             "reactionr": blank,
             "typing": blank,
             "dm_typing": blank,
-            "channel": [blank, 0]
+            "channel": [blank, 0],
         }
-
-        self._on_messagec = None
-        self._on_ready = None
-
+        self._act = None
         self.user = None
 
         self.api = DisApi(self.token, self.intflags)
 
         self.isready = False
 
-        self.__classname__ = "DisBot"
-
         self._logger.log("Bot created succesful!")
 
     @property
@@ -324,7 +272,62 @@ class DisBot:
     async def _on_close(self):
         pass
 
-    def on(self, event_type: Event(DisBotEventType, str)) -> Wrapper:
+    def event(self) -> Wrapper:
+        """event
+        Add event to bot
+
+        Returns:
+            Wrapper
+        """
+        def wrapper(func):
+            event_type: str = func.__name__
+
+            if event_type.startswith('on_'):
+                event_type = event_type.removeprefix('on_')
+
+            if event_type in _all_basic_events:
+                if event_type == "close":
+                    self._on_close = func
+                    self._logger.log("Register on_close() event")
+                else:
+                    if event_type in [
+                        "messagec",
+                        "messageu",
+                        "messaged",
+                        "typing",
+                        "dm_typing",
+                        "dmessagec",
+                        "dmessageu",
+                        "dmessaged",
+                    ]:
+                        if self.intflags >= DisFlags.messages():
+                            self._ons[event_type] = func
+                            self._logger.log(f"Register on_{event_type}() event")
+                        else:
+                            self._logger.log("Error: BotEventVisibleError")
+                            raise errors.BotEventVisibleError(
+                                "messagec(), typing(), dm_typing() and other events"
+                                + "don't avaivable right now because flags < DisFlags.messages()"
+                            )
+                    elif event_type in ["reaction", "reactionr"]:
+                        if self.intflags >= DisFlags.reactions():
+                            self._ons[event_type] = func
+                            self._logger.log(f"Register on_{event_type}() event")
+                        else:
+                            self._logger.log("Error: BotEventVisibleError")
+                            raise errors.BotEventVisibleError(
+                                "reaction() and reactionr() events don't"
+                                + " avaivable right now because flags < DisFlags.reactions()"
+                            )
+                    else:
+                        self._ons[event_type] = func
+                        self._logger.log(f"Register on_{event_type}() event")
+            else:
+                self._logger.log("Error: BotEventTypeError")
+                raise errors.BotEventTypeError("Invalid type of event!")
+        return wrapper
+
+    def on(self, event_type: TypeOf[DisBotEventType]) -> Wrapper:
         """
         This method was created for changing on_ready(), on_messagec()
         and other methods that using in _runner
@@ -336,9 +339,11 @@ class DisBot:
         __methodname__ = f"{self.__classname__}.on()"
 
         if isinstance(event_type, DisBotEventType):
-            _message = f"Error! In method {__methodname__} was moved" \
-                        "invalid argument! Argument type is DisBotEventType," \
-                        "but in method have to type is str!"
+            _message = (
+                f"Error! In method {__methodname__} was moved"
+                "invalid argument! Argument type is DisBotEventType,"
+                "but in method have to type is str!"
+            )
             raise errors.InvalidArgument(_message)
 
         def wrapper(func):
@@ -347,16 +352,25 @@ class DisBot:
                     self._on_close = func
                     self._logger.log("Register on_close() event")
                 else:
-                    if event_type in ["messagec", "messageu", "messaged", "typing", "dm_typing",
-                                "dmessagec", "dmessageu", "dmessaged"]:
+                    if event_type in [
+                        "messagec",
+                        "messageu",
+                        "messaged",
+                        "typing",
+                        "dm_typing",
+                        "dmessagec",
+                        "dmessageu",
+                        "dmessaged",
+                    ]:
                         if self.intflags >= DisFlags.messages():
                             self._ons[event_type] = func
                             self._logger.log(f"Register on_{event_type}() event")
                         else:
                             self._logger.log("Error: BotEventVisibleError")
                             raise errors.BotEventVisibleError(
-                                "messagec(), typing(), dm_typing() and other events" +
-                                "don't avaivable right now because flags < DisFlags.messages()")
+                                "messagec(), typing(), dm_typing() and other events"
+                                + "don't avaivable right now because flags < DisFlags.messages()"
+                            )
                     elif event_type in ["reaction", "reactionr"]:
                         if self.intflags >= DisFlags.reactions():
                             self._ons[event_type] = func
@@ -364,8 +378,9 @@ class DisBot:
                         else:
                             self._logger.log("Error: BotEventVisibleError")
                             raise errors.BotEventVisibleError(
-                                "reaction() and reactionr() events don't" +
-                                " avaivable right now because flags < DisFlags.reactions()")
+                                "reaction() and reactionr() events don't"
+                                + " avaivable right now because flags < DisFlags.reactions()"
+                            )
                     else:
                         self._ons[event_type] = func
                         self._logger.log(f"Register on_{event_type}() event")
@@ -375,7 +390,9 @@ class DisBot:
 
         return wrapper
 
-    def add_event(self, event_type: Event(DisBotEventType, str), func: Callable) -> None:
+    def add_event(
+        self, event_type: TypeOf[DisBotEventType], func: Callable
+    ) -> None:
         """
         Add event to bot with function and event type
         -----
@@ -386,9 +403,11 @@ class DisBot:
         __methodname__ = f"{self.__classname__}.add_event()"
 
         if isinstance(event_type, DisBotEventType):
-            _message = f"Error! In method {__methodname__} was moved" \
-                        "invalid argument! Argument type is DisBotEventType," \
-                        "but in method have to type is str!"
+            _message = (
+                f"Error! In method {__methodname__} was moved"
+                "invalid argument! Argument type is DisBotEventType,"
+                "but in method have to type is str!"
+            )
             raise errors.InvalidArgument(_message)
 
         if event_type in _all_basic_events:
@@ -413,7 +432,7 @@ class DisBot:
 
         return wrapper
 
-    def on_message(self, event_type: Literal['create', 'update', 'delete']) -> Wrapper:
+    def on_message(self, event_type: Literal["create", "update", "delete"]) -> Wrapper:
         """
         Method for changing on_message() events
         -----
@@ -423,13 +442,13 @@ class DisBot:
         _ts: List[str] = [
             "create",  # Message create
             "update",  # Message update
-            "delete"  # Message delete
+            "delete",  # Message delete
         ]
 
         _mse: List[str] = [
             "messagec",  # Message create
             "messageu",  # Message update
-            "messaged"  # Message delete
+            "messaged",  # Message delete
         ]
 
         def wrapper(func):
@@ -446,7 +465,9 @@ class DisBot:
 
         return wrapper
 
-    def on_dm_message(self, event_type: Literal['create', 'update', 'delete']) -> Wrapper:
+    def on_dm_message(
+        self, event_type: Literal["create", "update", "delete"]
+    ) -> Wrapper:
         """
         Method for changing on_dm_message() events
         -----
@@ -456,13 +477,13 @@ class DisBot:
         _ts: List[str] = [
             "create",  # Message create
             "update",  # Message update
-            "delete"  # Message delete
+            "delete",  # Message delete
         ]
 
         _mse: List[str] = [
             "dmessagec",  # Message create
             "dmessageu",  # Message update
-            "dmessaged"  # Message delete
+            "dmessaged",  # Message delete
         ]
 
         def wrapper(func):
@@ -486,6 +507,7 @@ class DisBot:
         :param channel_id: Channel id
         :return Wrapper:
         """
+
         def wrapper(func):
             self._logger.log("Register on_channel() event")
             self._ons["channel"] = [func, channel_id]
@@ -503,6 +525,7 @@ class DisBot:
         Returns:
             Wrapper
         """
+
         def wrapper(func, name=name):
             if name is MISSING:
                 try:
@@ -511,10 +534,10 @@ class DisBot:
                     name = func[1].__name__
 
             payload = {
-                    "name": name,
-                    "type": appc.ApplicationCommandType.TEXT_INPUT,
-                    "description": "No description"
-                }
+                "name": name,
+                "type": appc.ApplicationCommandType.TEXT_INPUT,
+                "description": "No description",
+            }
 
             try:
                 for key in list(func[0].keys()):
@@ -539,14 +562,12 @@ class DisBot:
             name (Optional[str], optional): Name of context menu. Defaults to MISSING.
                                             (if MISSING: func.__name__)
         """
+
         def wrapper(func, name=name):
             if name is MISSING:
                 name = func.__name__
 
-            payload = {
-                "name": name,
-                "type": None
-            }
+            payload = {"name": name, "type": None}
 
             # Get type of second argument of function
             sig = signature(func)
@@ -567,28 +588,28 @@ class DisBot:
 
             self._logger.log(message_to_log)
             self.api.create_command(payload, func)
+
         return wrapper
 
-    def run(self, status: Optional[Literal['online', 'dnd', 'invisible', 'idle']] = None,
-            activity: Optional[Union[Activity, dict]] = None) -> None:
+    def run(
+        self,
+        status: Literal["online", "dnd", "invisible", "idle"] = "online",
+        activity: Optional[Activity] = None,
+    ) -> None:
         """
         Running bot
         -----
         :param status: Status for bot user
         :return: None
         """
-        if isinstance(status, DisBotStatus):
-            raise errors.InvalidArgument("Invalid argument type!")
-
         self.isready = True
 
-        if status:
-            self.status = status
-        elif not status and not self.status:
-            self.status = "online"
+        self.status = status
 
         if activity:
-            self._act = activity
+            self._act = activity.json()
+        else:
+            self._act = None
 
         self._logger.log("Running bot")
 
@@ -601,15 +622,14 @@ class DisBot:
 
     async def _runner(self) -> None:
         try:
-            await self.api.run(self.status, self._ons,
-                               debug=self.debug, act=self._act)
+            await self.api.run(self.status, self._ons, debug=self.debug, act=self._act)
         except KeyboardInterrupt:
             self._write_logs()
             await self._on_close()
             await self.api.session.close()
             await self._dissconnenter()
         except requests.exceptions.ConnectionError:
-            self. _raise_internet_error()
+            self._raise_internet_error()
 
     async def disconnect(self) -> None:
         """
@@ -628,8 +648,12 @@ class DisBot:
             self._logger.log("Disconnect bot")
             await self.api.disconnecter()
 
-    async def send(self, channel_id: int, content: Optional[str] = None,
-                    embeds: Optional[List[DisEmbed]] = None):
+    async def send(
+        self,
+        channel_id: int,
+        content: Optional[str] = None,
+        embeds: Optional[List[DisEmbed]] = None,
+    ):
         """
         Send message to channel
         -----
@@ -659,7 +683,9 @@ class DisBot:
         _m = "This channel is not channel! Use get_thread() method"
         raise RuntimeError(_m)
 
-    def get_thread(self, thread_id: ThreadId) -> Union[DisNewsThread, DisThread, DisPrivateThread]:
+    def get_thread(
+        self, thread_id: ThreadId
+    ) -> Union[DisNewsThread, DisThread, DisPrivateThread]:
         """get_thread
         Get thread by id
 
@@ -712,28 +738,36 @@ class DisBot:
         elif isinstance(activity, dict):
             act = activity
 
-        await self.api.fsend_request({
-            "op": 3,
-            "d": {
-                "since": mktime(datetime.now().timetuple()) * 1000,
-                "afk": self.api.hook.isafk,
-                "status": self.status,
-                "activities": [act]
+        await self.api.fsend_request(
+            {
+                "op": 3,
+                "d": {
+                    "since": mktime(datetime.now().timetuple()) * 1000,
+                    "afk": self.api.hook.isafk,
+                    "status": self.status,
+                    "activities": [act],
+                },
             }
-        })
+        )
 
     def _write_logs(self):
         _datetime = datetime.now()
 
         tformat = "%d %d %d %d %d %d"
 
-        filename = tformat % (_datetime.year, _datetime.month, _datetime.day,
-                              _datetime.hour, _datetime.minute, _datetime.second)
+        filename = tformat % (
+            _datetime.year,
+            _datetime.month,
+            _datetime.day,
+            _datetime.hour,
+            _datetime.minute,
+            _datetime.second,
+        )
 
         filename += ".txt"
 
         current_directory = os.getcwd()
-        final_directory = os.path.join(current_directory, r'__logs__')
+        final_directory = os.path.join(current_directory, r"__logs__")
         if not os.path.exists(final_directory):
             os.makedirs(final_directory)
 
