@@ -22,13 +22,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-from typing import (
-    Optional,
-    Union,
-    List,
-    final,
-    TypedDict
-)
+from typing import Optional, Union, List, final, TypedDict
 
 from json import dumps
 from aiohttp import ClientSession
@@ -42,6 +36,7 @@ from disspy.guild import DisGuild
 from disspy.jsongenerators import _EmbedGenerator
 from disspy.ui import ActionRow
 from disspy.reaction import DisEmoji, DisOwnReaction
+from disspy.payloads import message_payload
 
 
 __all__: tuple = (
@@ -50,7 +45,7 @@ __all__: tuple = (
     "DmMessage",
     "DisDmChannel",
     "MessageDeleteEvent",
-    "DmMessageDeleteEvent"
+    "DmMessageDeleteEvent",
 )
 
 
@@ -58,6 +53,7 @@ class MessagePayload(TypedDict):
     """MessagePayload
     Text message payload (typed)
     """
+
     content: str
     embeds: Optional[list]
     components: Optional[list]
@@ -65,7 +61,9 @@ class MessagePayload(TypedDict):
 
 class _SendingRestHandler:
     @staticmethod
-    async def execute(channel_id: int, payload: MessagePayload, __session: ClientSession) -> dict:
+    async def execute(
+        channel_id: int, payload: MessagePayload, __session: ClientSession
+    ) -> dict:
         """execute
         Send messages in channels
 
@@ -155,7 +153,7 @@ class _GettingChannelData:
             dict: Json output
         """
         _u = f"https://discord.com/api/v10/channels/{channel_id}"
-        _h = {'Authorization': f'Bot {token}'}
+        _h = {"Authorization": f"Bot {token}"}
 
         return get(_u, headers=_h).json()
 
@@ -173,7 +171,7 @@ class _GettingChannelData:
             dict: Json output
         """
         _u = f"https://discord.com/api/v10/channels/{channel_id}/messages/{message_id}"
-        _h = {'Authorization': f'Bot {token}'}
+        _h = {"Authorization": f"Bot {token}"}
 
         return get(_u, headers=_h).json()
 
@@ -192,7 +190,7 @@ class _GettingGuildData:
             dict: Json output
         """
         _u = f"https://discord.com/api/v10/guilds/{guild_id}"
-        _h = {'Authorization': f'Bot {token}'}
+        _h = {"Authorization": f"Bot {token}"}
 
         return get(_u, headers=_h).json()
 
@@ -202,6 +200,7 @@ class DisMessage(Message):
     """
     Message in channel
     """
+
     def __init__(self, _data, __token, __session):
         super().__init__(_data["type"])
 
@@ -220,24 +219,36 @@ class DisMessage(Message):
                 _e = None
 
                 if i["footer"]["text"]:
-                    _e = DisEmbed(i["title"], i["description"], i["color"], i["footer"]["text"])
+                    _e = DisEmbed(
+                        title=i["title"],
+                        description=i["description"],
+                        color=i["color"],
+                        footer=i["footer"]["text"]
+                    )
                 else:
-                    _e = DisEmbed(i["title"], i["description"], i["color"])
+                    _e = DisEmbed(i["title"], description=i["description"], color=i["color"])
 
                 if i["fields"]:
                     for field in i["fields"]:
                         try:
-                            _e.add_field(field["name"], field["value"], field["inline"])
+                            _e.add_field(field["name"], field["value"], inline=field["inline"])
                         except KeyError:
                             _e.add_field(field["name"], field["value"])
 
+                self.embeds.append(_e)
+
         self.id: int = int(_data["id"])
 
         self._t = __token
         self.session = __session
 
-    async def reply(self, content: Optional[SupportsStr] = None,
-                    embeds: Optional[List[DisEmbed]] = None):
+    async def reply(
+        self,
+        content: Optional[SupportsStr] = None,
+        *,
+        embeds: Optional[List[DisEmbed]] = None,
+        action_row: Optional[ActionRow] = None
+    ):
         """reply
         Reply to message
 
@@ -245,32 +256,18 @@ class DisMessage(Message):
             content (Optional[str], optional): Message content (text). Defaults to None.
             embeds (Optional[List[DisEmbed]], optional): Message embeds (DisEmbed objects).
                                                          Defaults to None.
+            action_row (Optional[ActionRow], optional): Action row with components.
+                                                         Defaults to None.
         """
-        _d = {
-            "content": None,
-            "embeds": {},
-            "message_reference": {
-                "message_id": self.id
-            }
-        }
+        _payload = message_payload(content, embeds, action_row)
+        _payload.setdefault("message_reference", {"message_id": self.id})
 
-        content = str(content)
+        if _payload:
+            data = await _SendingRestHandler.execute(self.channel.id, _payload, self.session)
 
-        if content:
-            _d["content"] = content
+            return DisMessage(data, self._t, self.session)
 
-        if embeds:
-            embeds_jsons = []
-
-            for i in embeds:
-                embeds_jsons.append(_EmbedGenerator(i))
-
-            _d["embeds"] = embeds_jsons
-
-        if not embeds and not content:
-            return
-
-        await _SendingRestHandler.execute(self.channel.id, _d, self.session)
+        return None
 
     async def create_reaction(self, emoji: Union[DisEmoji, str]) -> DisOwnReaction:
         """create_reaction
@@ -289,7 +286,9 @@ class DisMessage(Message):
                 emoji = emoji.unicode
 
         await _SendingRestHandler.create_reaction(
-            f"/channels/{self.channel.id}/messages/{self.id}/reactions/{emoji}/@me", self.session)
+            f"/channels/{self.channel.id}/messages/{self.id}/reactions/{emoji}/@me",
+            self.session,
+        )
 
         return DisOwnReaction(emoji, self.id, self.channel.id, self._t, self.session)
 
@@ -297,7 +296,9 @@ class DisMessage(Message):
         """delete
         Delete message
         """
-        _u = f"https://discord.com/api/v10/channels/{self.channel.id}/messages/{self.id}"
+        _u = (
+            f"https://discord.com/api/v10/channels/{self.channel.id}/messages/{self.id}"
+        )
 
         await _SendingRestHandler.delete_message(_u, self.session)
 
@@ -307,6 +308,7 @@ class DisChannel(Channel):
     """
     The class for sending messages to discord channels and fetching messages in channels
     """
+
     def __init__(self, channel_id: int, __token, __session):
         """
         Creating an object DisChannel
@@ -341,44 +343,32 @@ class DisChannel(Channel):
         """
         return self.id == other.id
 
-    async def send(self, content: Optional[SupportsStr] = None,
-                   embeds: Optional[List[DisEmbed]] = None,
-                   action_row: Optional[ActionRow] = None) -> Union[DisMessage, None]:
+    async def send(
+        self,
+        content: Optional[SupportsStr] = None,
+        embeds: Optional[List[DisEmbed]] = None,
+        action_row: Optional[ActionRow] = None,
+    ) -> Union[DisMessage, None]:
+        """send
+        Send message in channels
+
+        Examples:
+            await channel.send("Test!")  # Send message with content
+
+            await channel.send("Test!", embeds=[DisEmbed()])  # Send message with content and embeds
+
+        Args:
+            content (Optional[SupportsStr], optional): Message content. Defaults to None.
+            embeds (Optional[List[DisEmbed]], optional): Message embeds (For one embed
+                                                         use `[your_embed]`). Defaults to None.
+            action_row (Optional[ActionRow], optional): Action row with components.
+                                                        Defaults to None.
+
+        Returns:
+            DisMessage: Sended message (If message is sended)
+            None: If message is not sended
         """
-        Sending messages to discord channel
-
-        :param content: str = None -> Content of message which will be sended (default is None)
-        :param embeds: List[DisEmbed] = None -> Embeds for message (DisEmbed - embed)
-                                                (default is None)
-        :param action_row: ActionRow = None -> Action Row with components (default is None)
-        :return DisMessage: Message which was sended
-        """
-        _payload = {
-            "content": None,
-            "embeds": None,
-            "components": None
-        }
-
-        if embeds:
-            embeds_json = []
-
-            for i in embeds:
-                embeds_json.append(_EmbedGenerator(i))
-
-            _payload["embeds"] = embeds_json
-        else:
-            del _payload["embeds"]
-
-        if content:
-            _payload["content"] = content
-        else:
-            del _payload["content"]
-
-        if action_row:
-            if action_row.json["components"]:
-                _payload["components"] = action_row.json
-            else:
-                del _payload["components"]
+        _payload = message_payload(content, embeds, action_row)
 
         if _payload:
             data = await _SendingRestHandler.execute(self.id, _payload, self.session)
@@ -442,6 +432,7 @@ class DmMessage(Message):
     """
     Message in DM channel
     """
+
     def __init__(self, data, token, session):
         super().__init__(data["type"], True)
 
@@ -454,8 +445,11 @@ class DmMessage(Message):
         self.content = data["content"]
         self.channel = DisDmChannel(data["channel_id"], self._t, session)
 
-    async def reply(self, content: Optional[SupportsStr] = None,
-                    embeds: Optional[List[DisEmbed]] = None):
+    async def reply(
+        self,
+        content: Optional[SupportsStr] = None,
+        embeds: Optional[List[DisEmbed]] = None,
+    ):
         """reply
         Reply to message
 
@@ -467,9 +461,7 @@ class DmMessage(Message):
         _d = {
             "content": None,
             "embeds": {},
-            "message_reference": {
-                "message_id": self.id
-            }
+            "message_reference": {"message_id": self.id},
         }
 
         content = str(content)
@@ -507,7 +499,9 @@ class DmMessage(Message):
                 emoji = emoji.unicode
 
         await _SendingRestHandler.create_reaction(
-            f"/channels/{self.channel.id}/messages/{self.id}/reactions/{emoji}/@me", self.session)
+            f"/channels/{self.channel.id}/messages/{self.id}/reactions/{emoji}/@me",
+            self.session,
+        )
 
         return DisOwnReaction(emoji, self.id, self.channel.id, self._t, self.session)
 
@@ -517,6 +511,7 @@ class DisDmChannel(Channel):
     """
     The class for sending messages to discord DMchannels and fetching messages in DMchannels
     """
+
     def __init__(self, dm_id: dict, __token, __session):
         """
         Init object
@@ -532,9 +527,12 @@ class DisDmChannel(Channel):
         self._t = __token
         self.session = __session
 
-    async def send(self, content: Optional[SupportsStr] = None,
-                   embeds: Optional[List[DisEmbed]] = None,
-                   action_row: Optional[ActionRow] = None) -> Union[DisMessage, None]:
+    async def send(
+        self,
+        content: Optional[SupportsStr] = None,
+        embeds: Optional[List[DisEmbed]] = None,
+        action_row: Optional[ActionRow] = None,
+    ) -> Union[DisMessage, None]:
         """
         Sending messages to discord channel
 
@@ -544,11 +542,7 @@ class DisDmChannel(Channel):
         :param action_row: ActionRow = None -> Action Row with components (default is None)
         :return DisMessage: Message which was sended
         """
-        _payload = {
-            "content": None,
-            "embeds": None,
-            "components": None
-        }
+        _payload = {"content": None, "embeds": None, "components": None}
 
         if embeds:
             embeds_json = []
@@ -594,15 +588,17 @@ class MessageDeleteEvent:
     """
     MESSAGE_DELETE event class with info about event
     """
+
     def __init__(self, data: dict, token: str, session):
-        self.message_id = data['id']
-        self.channel = DisChannel(data['channel_id'], token, session)
+        self.message_id = data["id"]
+        self.channel = DisChannel(data["channel_id"], token, session)
 
 
 class DmMessageDeleteEvent:
     """
     MESSAGE_DELETE event class with info about event, but in DM channel
     """
+
     def __init__(self, data: dict, token: str, session):
-        self.message_id = data['id']
-        self.channel = DisDmChannel(data['channel_id'], token, session)
+        self.message_id = data["id"]
+        self.channel = DisDmChannel(data["channel_id"], token, session)
